.. This file contains all links we use for documentation in a centralized place

.. _idiap: http://www.idiap.ch
.. _bob: http://www.idiap.ch/software/bob
.. _pypi: http://pypi.python.org
.. _mailing list: https://www.idiap.ch/software/bob/discuss
.. _scikit-learn: http://scikit-learn.org
